@@ -1,6 +1,7 @@
 import asyncio
 import os
 import types
+import re
 
 # 判断系统类型，如果是windows则引入wexpect，如果是linux则引入pexpect
 if os.name == 'nt':
@@ -26,6 +27,7 @@ class MyThread(threading.Thread):
         elif self.file_size.endswith('G'):
             self.file_size = int(float(self.file_size[:-1]) * 1024 * 1024 * 1024)
         self.file_name = file_name
+        print('文件名：', self.file_name)
         self.daemon = True
         self.start()
 
@@ -47,8 +49,20 @@ class MyThread(threading.Thread):
         while not self.is_stop:
             try:
                 time.sleep(0.5)
+                # 下载的文件为临时文件，会在原来的文件名后面加上.随机字符串，所以需要获取临时文件的大小
+                # 获取文件名
+                file_path = os.path.dirname(self.file_name)
+                file_name = os.path.basename(self.file_name)
+                # 获取临时文件名
+                file_name_list = os.listdir(file_path)
+                # print(file_name_list)
+                file_name = [i for i in file_name_list if i.startswith('.' + file_name + '.')][0]
+                # 如果为空，则continue
+                if not file_name:
+                    continue
+                # 获取文件名
                 # 获取文件大小
-                file_size = os.path.getsize(self.file_name)
+                file_size = os.path.getsize(file_name)
                 # 计算百分比
                 percent = file_size / self.file_size * 100
                 # 四舍五入取整
@@ -172,17 +186,24 @@ def ssh_get_file_list(remote_path, ip, user_name, password, port=22):
         ssh.close()
         return None
 
-
 @download_file
 def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22, callback=None):
-    # cmd = 'scp %s@%s:%s %s' % (user_name, ip, remote_path, local_path)
+     # cmd = 'scp %s@%s:%s %s' % (user_name, ip, remote_path, local_path)
     cmd = 'scp -P %s %s@%s:%s %s' % (port, user_name, ip, remote_path, local_path)
     print(cmd)
     ssh = pexpect.spawn(cmd)
     # 不设置超时时间，因为下载文件的时间不确定
     try:
+        get_file_size_index = 0
         # 获取文件大小
-        file_size = ssh_get_file_size(remote_path, ip, user_name, password, port)
+        while True:
+            file_size = ssh_get_file_size(remote_path, ip, user_name, password, port)
+            if file_size:
+                break
+            get_file_size_index += 1
+            if get_file_size_index > 3:
+                print('获取文件大小失败')
+                file_size = '0M'
         # 开启进度条打印线程
         file_name = remote_path.split('/')[-1]
         # 如果local_path没有以/结尾，则添加/
@@ -209,14 +230,66 @@ def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22,
         if isinstance(before_str, bytes):
             before_str = before_str.decode('utf-8')
         # print(f'ssh before: {before_str}')
-        if 'scp:' in before_str:
+        if 'rsync error' in before_str:
+            print('rsync error')
+            ssh.close()
             yield False
+        else:
+            print('rsync success')
+            ssh.close()
         yield True
     except pexpect.EOF:
         print('EOF')
         ssh.close()
         yield False
 
+    
+        
+
+# @download_file
+# def ssh_download_file(remote_path, local_path, ip, user_name, password, port=22, callback=None):
+#     # cmd = 'scp %s@%s:%s %s' % (user_name, ip, remote_path, local_path)
+#     cmd = 'scp -P %s %s@%s:%s %s' % (port, user_name, ip, remote_path, local_path)
+#     print(cmd)
+#     ssh = pexpect.spawn(cmd)
+#     # 不设置超时时间，因为下载文件的时间不确定
+#     try:
+#         # 获取文件大小
+#         file_size = ssh_get_file_size(remote_path, ip, user_name, password, port)
+#         # 开启进度条打印线程
+#         file_name = remote_path.split('/')[-1]
+#         # 如果local_path没有以/结尾，则添加/
+#         if local_path[-1] != '/':
+#             local_path += '/'
+#         local_file_path = local_path + file_name
+#         # 如果本地文件已经存在，则删除
+#         if os.path.exists(local_file_path):
+#             os.remove(local_file_path)
+#             time.sleep(1)
+#         i = ssh.expect([is_input_yes, password_key, pexpect.EOF, pexpect.TIMEOUT])
+#         if i == 0:
+#             ssh.sendline('yes')
+#             ssh.expect(password_key)
+#             ssh.sendline(password)
+#         elif i == 1:
+#             ssh.sendline(password)
+#         process_thread = MyThread(file_size=file_size, file_name=local_file_path)
+#         yield process_thread
+#         ssh.expect(pexpect.EOF, timeout=6000)
+#         process_thread.stop()
+#         # 如果下载失败
+#         before_str = ssh.before
+#         if isinstance(before_str, bytes):
+#             before_str = before_str.decode('utf-8')
+#         # print(f'ssh before: {before_str}')
+#         if 'scp:' in before_str:
+#             yield False
+#         yield True
+#     except pexpect.EOF:
+#         print('EOF')
+#         ssh.close()
+#         yield False
+
 
 def ssh_upload_file(local_path, remote_path, ip, user_name, password, port=22):
     # cmd = 'scp %s %s@%s:%s' % (local_path, user_name, ip, remote_path)
@@ -412,10 +485,6 @@ if __name__ == '__main__':
     password = 'Dxr85578595'
     res = ssh_download_file('/root/test.zip', './', ip, user_name, password, callback=process_callback)
     print(res)
-    res = ssh_download_file('/root/frp.tar.gz', './', ip, user_name, password, callback=process_callback)
-    print(res)
-    res = ssh_download_file('/root/VideoController.zip', './', ip, user_name, password, callback=process_callback)
-    print(res)
 
 
     
