@@ -98,16 +98,22 @@ def update_file_by_target_object(file, target_object, target_object_name):
     # yaml文件内容与目标对象匹配
     result = True
     if target_object_name in data.keys():
-        for x in target_object.keys():
-            if x in data[target_object_name].keys():
-                if type(target_object[x]) != type(data[target_object_name][x]):
+        if type(target_object) is type(data):
+            for x in target_object.keys():
+                if x in data[target_object_name].keys():
+                    if type(target_object[x]) != type(data[target_object_name][x]):
+                        result = False
+                        print_error("[" + x + "]" + "data type error, save failed")
+                        break
+                else:
                     result = False
-                    print_error("[" + x + "]" + "data type error, save failed")
+                    print_error("target_object do not has " + x)
                     break
-            else:
-                result = False
-                print_error("target_object do not has " + x)
-                break
+        else:
+            if target_object_name in data.keys():
+                if type(target_object) != type(data[target_object_name]):
+                    result = False
+                    print_error("[" + target_object_name + "]" + "data type error, save failed")
     else:
         result = False
         print_error("config file do not has " + target_object_name)
@@ -115,7 +121,7 @@ def update_file_by_target_object(file, target_object, target_object_name):
     if result:
         data[target_object_name] = target_object
         fd_1 = open(file, "w", encoding="utf-8")
-        str_temp = yaml.dump(data)
+        str_temp = yaml.dump(data, allow_unicode=True)
         fd_1.write(str_temp)
         fd_1.close()
         return True
@@ -135,7 +141,7 @@ def update_file_all(file, target_object):
         target = re.split(r'[/,\\]', file)[-1]
         print_info("start open " + target)
         fd = open(file, "w", encoding="utf-8")
-        str_temp = yaml.dump(target_object)
+        str_temp = yaml.dump(target_object, allow_unicode=True)
         fd.write(str_temp)
         fd.close()
         return True
